/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: swift.h 96 2004-09-07 18:20:37Z aquamaniac $
 begin       : Mon May 02 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQHBCIBANK_SWIFT_H
#define AQHBCIBANK_SWIFT_H

/**
 * @defgroup MOD_PLUGIN_SWIFT SWIFT Parser
 * @ingroup MOD_PLUGINS
 *
 * <p>
 * This DBIO plugin allows parsing and creating of SWIFT documents.
 * </p>
 * <p>
 * Every DBIO plugin uses a GWEN_DB which contains the configuration for
 * the given plugin. For this plugin the configuration is as follows:
 * </p>
 * <table>
 *
 * <tr>
 *   <td><b>Name</b></td>
 *   <td><b>Type</b></td>
 *   <td><b>Content</b></td>
 *   <td><b>Mode</b></td>
 * </tr>
 *
 * <tr>
 *   <td><b>type</b></td>
 *   <td>char</td>
 *   <td><i>mt940</i>, <i>mt942</i>: type of SWIFT document</td>
 *   <td>required</td>
 * </tr>
 *
 * </table>
 *
 */


#endif /* AQHBCIBANK_SWIFT_H */
